/* 
 *
 * $Id: k3bdeviceoptiontab.h 619556 2007-01-03 17:38:12Z trueg $
 * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
 *
 * This file is part of the K3b project.
 * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.
 */


#ifndef K3B_DEVICE_OPTIONTAB_H
#define K3B_DEVICE_OPTIONTAB_H

#include <tqwidget.h>

class TQLabel;
class K3bDeviceWidget;


class K3bDeviceOptionTab : public TQWidget
{
TQ_OBJECT
  

 public:
  K3bDeviceOptionTab( TQWidget*, const char* name = 0 );
  ~K3bDeviceOptionTab();

  void readDevices();
  void saveDevices();

 private slots:
  void slotRefreshButtonClicked();

 private:
  TQLabel*          m_labelDevicesInfo;
  K3bDeviceWidget* m_deviceWidget;
};



#endif
